==> intelliw-1.1.0.tar.gz: intelliw-1.1.0/setup.py <==
# coding=utf-8
import shutil
from intelliw import __version__
from setuptools import setup, find_packages

import intelliw


def move_base_file(infile, outfile):
    """move intelliw/scaffolding/resources/iw.py to workdir """
    shutil.copy(infile, outfile)


def parse_requirements(filename):
    """ load requirements from a pip requirements file. (replacing from pip.req import parse_requirements)"""
    lines = (line.strip() for line in open(filename))
    return [line for line in lines if line and not line.startswith("#")]


def long_description_load(filename):
    with open(filename, "r", encoding="utf-8") as fh:
        long_description = fh.read()
    return long_description


reqs = parse_requirements('intelliw/scaffolding/resources/requirements.txt')
long_description = long_description_load('README.rst')

setup(
    name='intelliw',
    version=__version__,
    author='yonyou',
    author_email='yonyou@yonyou.com',
    url="http://git.yonyou.com/iuapaipaas/iw-algo-fx",
    python_requires='>=3.6',


    description='An easy to start Intelligent Workshop Algorithm Framework',
    long_description=long_description,
    long_description_content_type="text/x-rst",


    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Operating System :: OS Independent',
    ],


    packages=find_packages(exclude=['packages', 'packages.lightgbm', 'intelliw.server', 'intelliw.server.datasets', 'intelliw.server.transforms', 'intelliw.server.utils']),
    install_requires=reqs,
    include_package_data=True,

    entry_points={
        'console_scripts': [
            'intelliw = intelliw.scaffolding.resources.iw:run'
        ]
    },
)

==> intelliw-1.1.9.tar.gz: intelliw-1.1.9/setup.py <==
# coding=utf-8
import shutil
from intelliw import __version__
from setuptools import setup, find_packages


def move_base_file(infile, outfile):
    """move intelliw/scaffolding/resources/iw.py to workdir """
    shutil.copy(infile, outfile)


def parse_requirements(filename):
    """ load requirements from a pip requirements file. (replacing from pip.req import parse_requirements)"""
    lines = (line.strip() for line in open(filename))
    return [line for line in lines if line and not line.startswith("#")]


def long_description_load(filename):
    with open(filename, "r", encoding="utf-8") as fh:
        long_description = fh.read()
    return long_description


reqs = parse_requirements('intelliw/requirements.txt')
long_description = long_description_load('README.rst')

setup(
    name='intelliw',
    version=__version__,
    author='yonyou',
    author_email='yonyou@yonyou.com',
    url="http://git.yonyou.com/iuapaipaas/iw-algo-fx",
    python_requires='>=3.6',


    description='An easy to start Intelligent Workshop Algorithm Framework',
    long_description=long_description,
    long_description_content_type="text/x-rst",


    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Operating System :: OS Independent',
    ],


    packages=find_packages(),
    install_requires=reqs,
    include_package_data=True,

    entry_points={
        'console_scripts': [
            'intelliw = intelliw.scaffolding.resources.iw:run',
            'intelliw_server = intelliw.interface.controller:run',
        ]
    },

)
